# Generated by Django 4.2.10 on 2024-03-18 13:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0028_claimattachmenttype_claimattachment_predefined_type'),
        ('claim', '0029_rename_pcpdate_claimserviceitem_created_date_and_more'),
    ]

    operations = [
    ]
