# Generated by Django 3.2.16 on 2023-01-26 09:03

import core.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0012_item_service_jsonExtField'),
    ]

    operations = [
        migrations.CreateModel(
            name='FeedbackPrompt',
            fields=[
                ('id', models.AutoField(db_column='FeedbackPromptID', primary_key=True, serialize=False)),
                ('feedback_prompt_date', core.fields.DateField(blank=True, db_column='FeedbackPromptDate', null=True)),
                ('officer_id', models.IntegerField(blank=True, db_column='OfficerID', null=True)),
                ('phone_number', models.CharField(db_column='PhoneNumber', max_length=36, null=True, blank=True)),
                ('sms_status', models.IntegerField(blank=True, db_column='SMSStatus', null=True)),
                ('validity_from', core.fields.DateTimeField(blank=True, db_column='ValidityFrom', null=True)),
                ('validity_to', core.fields.DateTimeField(blank=True, db_column='ValidityTo', null=True)),
                ('legacy_id', models.IntegerField(blank=True, db_column='LegacyID', null=True)),
                ('audit_user_id', models.IntegerField(blank=True, db_column='AuditUserID', null=True)),
            ],
            options={
                'db_table': 'tblFeedbackPrompt',
                'managed': False,
            },
        ),
    ]
