# Generated by Django 3.0.3 on 2020-06-11 06:01
from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0009_auto_20200421_1657'),
    ]

    operations = [
        migrations.DeleteModel(
            name='BatchRun',
        ),
        migrations.DeleteModel(
            name='ClaimDiagnosisCode',
        ),
        migrations.DeleteModel(
            name='Officer',
        ),
        migrations.RunSQL('ALTER TABLE [tblClaim] ADD [JsonExt] TEXT'
                          if settings.MSSQL else
                          'ALTER TABLE "tblClaim" ADD "JsonExt" jsonb')
    ]
