# Generated by Django 2.1.14 on 2020-03-18 10:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0005_claimmutation'),
    ]

    operations = [
        migrations.AddField(
            model_name='claimattachment',
            name='url',
            field=models.TextField(blank=True, null=True),
        ),
    ]
