# Generated by Django 3.2.16 on 2023-07-05 14:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0019_auto_20230615_1055'),
    ]

    operations = [
        migrations.AlterField(
            model_name='claim',
            name='code',
            field=models.CharField(db_column='ClaimCode', max_length=50),
        ),
    ]
