# Generated by Django 3.2.19 on 2023-12-05 14:55

from django.db import migrations, models
import django.db.models.deletion
from django.conf import settings

class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0025_auto_20231205_1455'),
    ]

    operations = [
        migrations.RunSQL(sql="""
            CREATE SEQUENCE IF NOT EXISTS tblfeedbackprompt_feedbackpromptid_seq;

            SELECT setval('tblfeedbackprompt_feedbackpromptid_seq', COALESCE((SELECT MAX("FeedbackPromptID") FROM "tblFeedbackPrompt"), 0) + 1, false);

            ALTER TABLE public."tblFeedbackPrompt"
            ALTER COLUMN "FeedbackPromptID" SET DEFAULT nextval('tblfeedbackprompt_feedbackpromptid_seq');

            ALTER SEQUENCE tblfeedbackprompt_feedbackpromptid_seq OWNED BY public."tblFeedbackPrompt"."FeedbackPromptID";
        """, reverse_sql=""),
        
    ] if not settings.MSSQL else []
