# Generated by Django 3.2.16 on 2023-03-20 09:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0013_feedbackprompt'),
    ]

    operations = [
        migrations.AlterField(
            model_name='claimadmin',
            name='code',
            field=models.CharField(max_length=50, blank=True, null=True),
        ),
    ]
