# Generated by Django 3.2.16 on 2023-08-22 07:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0021_auto_20230818_0914'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feedbackprompt',
            name='phone_number',
            field=models.CharField(db_column='PhoneNumber', max_length=50, null=True, blank=True),
        ),
    ]
