# Generated by Django 2.1.14 on 2020-03-18 14:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0006_claimattachment_url'),
    ]

    operations = [
        migrations.AlterField(
            model_name='claimattachment',
            name='legacy_id',
            field=models.UUIDField(blank=True, db_column='LegacyID', null=True),
        ),
    ]
