# Generated by Django 3.2.18 on 2023-05-15 09:49

import core.fields
import datetime
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('insuree', '0013_auto_20211103_1023'),
        ('location', '0013_auto_20230317_1534'),
        ('claim_batch', '0006_capitationpayment'),
        ('core', '0019_extended_field'),
        ('product', '0006_insert_ceiling_type'),
        ('policy', '0004_add_medical_oficer_reading_rights'),
        ('medical', '0003_mutations'),
        ('claim', '0015_prohibit_interaction_for_enrolment_officer'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='claim',
            name='row_id',
        ),
        migrations.RemoveField(
            model_name='claimadmin',
            name='row_id',
        ),
        migrations.AddField(
            model_name='claim',
            name='adjuster',
            field=models.ForeignKey(blank=True, db_column='Adjuster', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.interactiveuser'),
        ),
        migrations.AddField(
            model_name='claim',
            name='admin',
            field=models.ForeignKey(blank=True, db_column='ClaimAdminId', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='claim.claimadmin'),
        ),
        migrations.AddField(
            model_name='claim',
            name='batch_run',
            field=models.ForeignKey(blank=True, db_column='RunID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='claim_batch.batchrun'),
        ),
        migrations.AddField(
            model_name='claim',
            name='feedback',
            field=models.OneToOneField(blank=True, db_column='FeedbackID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='claim.feedback'),
        ),
        migrations.AddField(
            model_name='claim',
            name='feedback_available',
            field=models.BooleanField(db_column='Feedback', default=False),
        ),
        migrations.AddField(
            model_name='claim',
            name='health_facility',
            field=models.ForeignKey(db_column='HFID', on_delete=django.db.models.deletion.DO_NOTHING, to='location.healthfacility'),
        ),
        migrations.AddField(
            model_name='claim',
            name='icd',
            field=models.ForeignKey(db_column='ICDID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_icds', to='medical.diagnosis'),
        ),
        migrations.AddField(
            model_name='claim',
            name='insuree',
            field=models.ForeignKey(db_column='InsureeID', on_delete=django.db.models.deletion.DO_NOTHING, to='insuree.insuree'),
        ),
        migrations.AddField(
            model_name='claim',
            name='json_ext',
            field=models.JSONField(blank=True, db_column='JsonExt', null=True),
        ),
        migrations.AddField(
            model_name='claim',
            name='uuid',
            field=models.CharField(db_column='ClaimUUID', default=uuid.uuid4, max_length=36, unique=True),
        ),
        migrations.AddField(
            model_name='claimadmin',
            name='has_login',
            field=models.BooleanField(blank=True, db_column='HasLogin', null=True),
        ),
        migrations.AddField(
            model_name='claimadmin',
            name='health_facility',
            field=models.ForeignKey(blank=True, db_column='HFId', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='location.healthfacility'),
        ),
        migrations.AddField(
            model_name='claimadmin',
            name='uuid',
            field=models.CharField(db_column='ClaimAdminUUID', default=uuid.uuid4, max_length=36, unique=True),
        ),
        migrations.AddField(
            model_name='claimdedrem',
            name='claim',
            field=models.ForeignKey(db_column='ClaimID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='dedrems', to='claim.claim'),
        ),
        migrations.AddField(
            model_name='claimdedrem',
            name='insuree',
            field=models.ForeignKey(blank=True, db_column='InsureeID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_ded_rems', to='insuree.insuree'),
        ),
        migrations.AddField(
            model_name='claimdedrem',
            name='policy',
            field=models.ForeignKey(blank=True, db_column='PolicyID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_ded_rems', to='policy.policy'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='claim',
            field=models.ForeignKey(db_column='ClaimID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='items', to='claim.claim'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='item',
            field=models.ForeignKey(db_column='ItemID', on_delete=django.db.models.deletion.DO_NOTHING, to='medical.item'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='json_ext',
            field=models.JSONField(blank=True, db_column='JsonExt', null=True),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='policy',
            field=models.ForeignKey(blank=True, db_column='PolicyID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='policy.policy'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='product',
            field=models.ForeignKey(blank=True, db_column='ProdID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_items', to='product.product'),
        ),
        migrations.AddField(
            model_name='claimservice',
            name='claim',
            field=models.ForeignKey(db_column='ClaimID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='services', to='claim.claim'),
        ),
        migrations.AddField(
            model_name='claimservice',
            name='json_ext',
            field=models.JSONField(blank=True, db_column='JsonExt', null=True),
        ),
        migrations.AddField(
            model_name='claimservice',
            name='policy',
            field=models.ForeignKey(blank=True, db_column='PolicyID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='policy.policy'),
        ),
        migrations.AddField(
            model_name='claimservice',
            name='product',
            field=models.ForeignKey(blank=True, db_column='ProdID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_services', to='product.product'),
        ),
        migrations.AddField(
            model_name='claimservice',
            name='service',
            field=models.ForeignKey(db_column='ServiceID', on_delete=django.db.models.deletion.DO_NOTHING, to='medical.service'),
        ),
        migrations.AddField(
            model_name='feedback',
            name='claim',
            field=models.OneToOneField(blank=True, db_column='ClaimID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='claim.claim'),
        ),
        migrations.AddField(
            model_name='feedback',
            name='uuid',
            field=models.CharField(db_column='FeedbackUUID', default=uuid.uuid4, max_length=36, unique=True),
        ),
        migrations.AddField(
            model_name='feedbackprompt',
            name='claim_id',
            field=models.OneToOneField(blank=True, db_column='ClaimID', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='claim.claim'),
        ),
        migrations.AlterField(
            model_name='claim',
            name='approval_status',
            field=models.SmallIntegerField(blank=True, db_column='ApprovalStatus', default=1, null=True),
        ),
        migrations.AlterField(
            model_name='claim',
            name='code',
            field=models.CharField(db_column='ClaimCode', max_length=8, unique=True),
        ),
        migrations.AlterField(
            model_name='claim',
            name='feedback_status',
            field=models.SmallIntegerField(blank=True, db_column='FeedbackStatus', default=1, null=True),
        ),
        migrations.AlterField(
            model_name='claim',
            name='icd_1',
            field=models.ForeignKey(blank=True, db_column='ICDID1', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_icd1s', to='medical.diagnosis'),
        ),
        migrations.AlterField(
            model_name='claim',
            name='icd_2',
            field=models.ForeignKey(blank=True, db_column='ICDID2', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_icd2s', to='medical.diagnosis'),
        ),
        migrations.AlterField(
            model_name='claim',
            name='icd_3',
            field=models.ForeignKey(blank=True, db_column='ICDID3', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_icd3s', to='medical.diagnosis'),
        ),
        migrations.AlterField(
            model_name='claim',
            name='icd_4',
            field=models.ForeignKey(blank=True, db_column='ICDID4', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='claim_icd4s', to='medical.diagnosis'),
        ),
        migrations.AlterField(
            model_name='claim',
            name='rejection_reason',
            field=models.SmallIntegerField(blank=True, db_column='RejectionReason', default=0, null=True),
        ),
        migrations.AlterField(
            model_name='claim',
            name='review_status',
            field=models.SmallIntegerField(blank=True, db_column='ReviewStatus', default=1, null=True),
        ),
        migrations.AlterField(
            model_name='claim',
            name='validity_from',
            field=core.fields.DateTimeField(db_column='ValidityFrom', default=datetime.datetime.now),
        ),
        migrations.AlterField(
            model_name='claimadmin',
            name='code',
            field=models.CharField(blank=True, db_column='ClaimAdminCode', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='claimadmin',
            name='legacy_id',
            field=models.IntegerField(blank=True, db_column='LegacyID', null=True),
        ),
        migrations.AlterField(
            model_name='claimadmin',
            name='validity_from',
            field=core.fields.DateTimeField(db_column='ValidityFrom', default=datetime.datetime.now),
        ),
        migrations.AlterField(
            model_name='claimitem',
            name='validity_from',
            field=core.fields.DateTimeField(db_column='ValidityFrom', default=datetime.datetime.now),
        ),
        migrations.AlterField(
            model_name='claimservice',
            name='validity_from',
            field=core.fields.DateTimeField(db_column='ValidityFrom', default=datetime.datetime.now),
        ),
        migrations.AlterField(
            model_name='feedback',
            name='validity_from',
            field=core.fields.DateTimeField(db_column='ValidityFrom', default=datetime.datetime.now),
        ),
    ]
