# Generated by Django 3.0.3 on 2020-11-26 12:44

import core.fields
import core.utils
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('claim', '0010_auto_20200611_0601'),
    ]

    operations = [
        migrations.AlterField(
            model_name='claimattachment',
            name='date',
            field=core.fields.DateField(blank=True, default=core.utils.TimeUtils.now),
        ),
    ]
